==> malon-account-source-2.0.tar.gz: accountData.rb <==
$:.unshift('./lib')
require 'csv'

class AccountRecord

	def initialize(csv_cell)

		if csv_cell == nil then return end

		if @variable_list == nil then
			fail "@variable_list is nil"
		end

		if @var_kind_list == nil then
			fail "@var_kind_list is nil"
		end

		vars = @variable_list
		vars.each_with_index do |var, i|
			if @var_kind_list[i] == "string" then
				eval("#{var} = csv_cell[#{i}].data.strip")
			else
				eval("#{var} = csv_cell[#{i}].data.to_f")
			end
		end		
	end

	def init_with_args(*args)
		if @variable_list == nil then
			fail "@variable_list is nil"
		end

		vars = @variable_list
		vars.each_with_index do |var, i|
			eval("#{var} = args[#{i}]")
		end		
	end

	def data
		result = ""
		vars = @variable_list
		vars.each do |var|
			# ޤޤޤƤǡϥ֥륯ơǰϤ
			if eval(var).kind_of?(String) and eval(var).include?(',') then
				result = result + '"' + eval(var).to_s + '"' + ","
			else
				result = result + eval(var).to_s + ","
			end
		end
		return (result.chop + "\n")
	end
end


class AccountDataList

	#
	# path : CSVե
	# class_name  : CSV쥳ɤΥ֥Ȥɽ饹̾
	#
	# CSVե뤬¸ߤʤϡadd᥽åɤƤФ줿ǥե뤬
	#
	def initialize(path, class_name)
		@file_path    = path
		@record_class = class_name
		@record_array = Array.new

		if File.exist?(@file_path) then
			CSV.open(@file_path, "r") do |row|
				@record_array.push( eval(@record_class).new(row) )
			end
		end
	end
	
    def each_with_index(&block)
		@record_array.each_with_index(&block)
	end

	def each(&block)
		@record_array.each(&block)
	end

	def value_at(index)
		return @record_array[index]
	end

	def add(record)
		if record.kind_of?(eval(@record_class)) then
			@record_array.push(record)
			fh = open(@file_path, "a")
			fh.write(record.data)
			fh.close
			
		else
			fail "This AccountDataList is #{@record_class} only"
		end		
	end

	def modify(record, index)
		if record.kind_of?(eval(@record_class)) then
			@record_array[index] = record
			fh = open(@file_path, "w")
			@record_array.each do |element|
				fh.write(element.data)
			end
			fh.close
		else
			fail "This AccountDataList is #{@record_class} only"
		end		
	end

	def delete(index)
		@record_array.delete_at(index)
		fh = open(@file_path, "w")
		@record_array.each do |element|
			fh.write(element.data)
		end
		fh.close
	end
end


=begin TEST CODE
class Sample  < AccountRecord
	def initialize(csv_cell)
		@v1 = nil
		@v2 = nil
		@v3 = nil
		@variable_list = ["@v1", "@v2", "@v3"]
		super
	end

	attr_reader :v1,:v2,:v3
end

list = AccountDataList.new("sample.csv", "Sample")
r = Sample.new(nil)
r.init_with_args("this is","modified", 0.9)
list.delete(1)

=end

==> malon-account-source-2.1.tar.gz: accountData.rb <==
$:.unshift('./lib')
require 'csv'

class AccountRecord

	def initialize(csv_cell)

		if csv_cell == nil then return end

		if @variable_list == nil then
			fail "@variable_list is nil"
		end

		if @var_kind_list == nil then
			fail "@var_kind_list is nil"
		end

		vars = @variable_list
		vars.each_with_index do |var, i|
			if @var_kind_list[i] == "string" then
				eval("#{var} = csv_cell[#{i}].data.strip")
			else
				eval("#{var} = csv_cell[#{i}].data.to_f")
			end
		end		
	end

	def init_with_args(*args)
		if @variable_list == nil then
			fail "@variable_list is nil"
		end

		vars = @variable_list
		vars.each_with_index do |var, i|
			eval("#{var} = args[#{i}]")
		end		
	end

	def data
		result = ""
		vars = @variable_list
		vars.each do |var|
			# ޤޤޤƤǡϥ֥륯ơǰϤ
			if eval(var).kind_of?(String) and eval(var).include?(',') then
				result = result + '"' + eval(var).to_s + '"' + ","
			else
				result = result + eval(var).to_s + ","
			end
		end
		return (result.chop + "\n")
	end
end


class AccountDataList

	#
	# path : CSVե
	# class_name  : CSV쥳ɤΥ֥Ȥɽ饹̾
	#
	# CSVե뤬¸ߤʤϡadd᥽åɤƤФ줿ǥե뤬
	#
	def initialize(path, class_name)
		@file_path    = path
		@record_class = class_name
		@record_array = Array.new

		if File.exist?(@file_path) then
			CSV.open(@file_path, "r") do |row|
				@record_array.push( eval(@record_class).new(row) )
			end
		end
	end
	
    def each_with_index(&block)
		@record_array.each_with_index(&block)
	end

	def each(&block)
		@record_array.each(&block)
	end

	def value_at(index)
		return @record_array[index]
	end

	def add(record)
		if record.kind_of?(eval(@record_class)) then
			@record_array.push(record)
			fh = open(@file_path, "a")
			fh.write(record.data)
			fh.close
			
		else
			fail "This AccountDataList is #{@record_class} only"
		end		
	end

	def modify(record, index)
		if record.kind_of?(eval(@record_class)) then
			@record_array[index] = record
			fh = open(@file_path, "w")
			@record_array.each do |element|
				fh.write(element.data)
			end
			fh.close
		else
			fail "This AccountDataList is #{@record_class} only"
		end		
	end

	def to_top(record)
		@record_array.delete(record)
		@record_array.unshift(record)
		fh = open(@file_path, "w")
		@record_array.each do |element|
			fh.write(element.data)
		end
		fh.close
	end
end


=begin TEST CODE
class Sample  < AccountRecord
	def initialize(csv_cell)
		@v1 = nil
		@v2 = nil
		@v3 = nil
		@variable_list = ["@v1", "@v2", "@v3"]
		super
	end

	attr_reader :v1,:v2,:v3
end

list = AccountDataList.new("sample.csv", "Sample")
r = Sample.new(nil)
r.init_with_args("this is","modified", 0.9)
list.delete(1)

=end
